@@ -35,6 +35,7 @@ except ImportError:
     def getpgid():
         """win32 getpgid implementation"""
 
+
 from os.path import exists, join, isfile, isdir, dirname, abspath
 
 from logilab.common.clcommands import CommandLine
@@ -234,9 +235,9 @@ class ListCommand(Command):
                     tinfo = cwcfg.cube_pkginfo(cube)
                     tversion = tinfo.version
                     cfgpb.add_cube(cube, tversion)
-                except ConfigurationError:
+                except ConfigurationError, ex:
                     tinfo = None
-                    tversion = '[missing cube information]'
+                    tversion = '[missing cube information: %s]' % ex
                 print '* %s %s' % (cube.ljust(namesize), tversion)
                 if self.config.verbose:
                     if tinfo:
@@ -282,15 +283,15 @@ class ListCommand(Command):
             print 'Warnings:\n', '\n'.join('* '+txt for txt in cfgpb.warnings)
         if cfgpb.errors:
             print 'Errors:'
-            for op, cube, version in cfgpb.errors:
+            for op, cube, version, src in cfgpb.errors:
                 if op == 'add':
                     print '* cube', cube,
                     if version:
                         print ' version', version,
-                    print 'is not installed, but required by %s' % ' '.join(cfgpb.reverse_constraints[cube])
+                    print 'is not installed, but required by %s' % src
                 else:
-                    print '* cube %s version %s is installed, but version %s is required by (%s)' % (
-                        cube, cfgpb.cubes[cube], version, ', '.join(cfgpb.reverse_constraints[cube]))
+                    print '* cube %s version %s is installed, but version %s is required by %s' % (
+                        cube, cfgpb.cubes[cube], version, src)
 
 class CreateInstanceCommand(Command):
     """Create an instance from a cube. This is an unified
@@ -493,7 +494,8 @@ running.'}),
             msg = "%s seems to be running. Remove %s by hand if necessary or use \
 the --force option."
             raise ExecutionError(msg % (appid, pidf))
-        helper.start_server(config)
+        if helper.start_server(config) == 1:
+            print 'instance %s started' % appid
 
 
 def init_cmdline_log_threshold(config, loglevel):
@@ -952,6 +954,9 @@ for cmdcls in (ListCommand,
 
 def run(args):
     """command line tool"""
+    import os
+    sys.stdout = os.fdopen(sys.stdout.fileno(), 'w', 0)
+    sys.stderr = os.fdopen(sys.stderr.fileno(), 'w', 0)
     cwcfg.load_cwctl_plugins()
     try:
         CWCTL.run(args)
