@@ -27,6 +27,7 @@ from warnings import warn
 from logilab.mtconverter import TransformError
 from logilab.common.decorators import cached
 
+from cubicweb import ValidationError
 from cubicweb.view import EntityAdapter, implements_adapter_compat
 from cubicweb.selectors import (implements, is_instance, relation_possible,
                                 match_exception)
@@ -483,5 +484,5 @@ class IUserFriendlyUniqueTogether(IUserFriendlyError):
     def raise_user_exception(self):
         etype, rtypes = self.exc.args
         msg = self._cw._('violates unique_together constraints (%s)') % (
-            ', '.join(self._cw._(rtypes)))
+            ', '.join([self._cw._(rtype) for rtype in rtypes]))
         raise ValidationError(self.entity.eid, dict((col, msg) for col in rtypes))
