@@ -44,16 +44,16 @@ class MetadataTC(BaseEntityTC):
         self.login(u'member')
         entity = self.request().create_entity('Bookmark', title=u"hello", path=u'project/cubicweb')
         self.commit()
-        self.assertEquals(entity.creator.eid, self.member.eid)
-        self.assertEquals(entity.dc_creator(), u'member')
+        self.assertEqual(entity.creator.eid, self.member.eid)
+        self.assertEqual(entity.dc_creator(), u'member')
 
     def test_type(self):
-        self.assertEquals(self.member.dc_type(), 'cwuser')
+        self.assertEqual(self.member.dc_type(), 'cwuser')
 
     def test_entity_meta_attributes(self):
         # XXX move to yams
-        self.assertEquals(self.schema['CWUser'].meta_attributes(), {})
-        self.assertEquals(dict((str(k), v) for k, v in self.schema['State'].meta_attributes().iteritems()),
+        self.assertEqual(self.schema['CWUser'].meta_attributes(), {})
+        self.assertEqual(dict((str(k), v) for k, v in self.schema['State'].meta_attributes().iteritems()),
                           {'description_format': ('format', 'description')})
 
 
@@ -63,20 +63,20 @@ class EmailAddressTC(BaseEntityTC):
         email2 = self.execute('INSERT EmailAddress X: X address "maarten@philips.com"').get_entity(0, 0)
         email3 = self.execute('INSERT EmailAddress X: X address "toto@logilab.fr"').get_entity(0, 0)
         email1.set_relations(prefered_form=email2)
-        self.assertEquals(email1.prefered.eid, email2.eid)
-        self.assertEquals(email2.prefered.eid, email2.eid)
-        self.assertEquals(email3.prefered.eid, email3.eid)
+        self.assertEqual(email1.prefered.eid, email2.eid)
+        self.assertEqual(email2.prefered.eid, email2.eid)
+        self.assertEqual(email3.prefered.eid, email3.eid)
 
     def test_mangling(self):
         email = self.execute('INSERT EmailAddress X: X address "maarten.ter.huurne@philips.com"').get_entity(0, 0)
-        self.assertEquals(email.display_address(), 'maarten.ter.huurne@philips.com')
-        self.assertEquals(email.printable_value('address'), 'maarten.ter.huurne@philips.com')
+        self.assertEqual(email.display_address(), 'maarten.ter.huurne@philips.com')
+        self.assertEqual(email.printable_value('address'), 'maarten.ter.huurne@philips.com')
         self.vreg.config.global_set_option('mangle-emails', True)
-        self.assertEquals(email.display_address(), 'maarten.ter.huurne at philips dot com')
-        self.assertEquals(email.printable_value('address'), 'maarten.ter.huurne at philips dot com')
+        self.assertEqual(email.display_address(), 'maarten.ter.huurne at philips dot com')
+        self.assertEqual(email.printable_value('address'), 'maarten.ter.huurne at philips dot com')
         email = self.execute('INSERT EmailAddress X: X address "syt"').get_entity(0, 0)
-        self.assertEquals(email.display_address(), 'syt')
-        self.assertEquals(email.printable_value('address'), 'syt')
+        self.assertEqual(email.display_address(), 'syt')
+        self.assertEqual(email.printable_value('address'), 'syt')
 
 
 class CWUserTC(BaseEntityTC):
@@ -94,19 +94,19 @@ class CWUserTC(BaseEntityTC):
 
     def test_dc_title_and_name(self):
         e = self.execute('CWUser U WHERE U login "member"').get_entity(0, 0)
-        self.assertEquals(e.dc_title(), 'member')
-        self.assertEquals(e.name(), 'member')
+        self.assertEqual(e.dc_title(), 'member')
+        self.assertEqual(e.name(), 'member')
         e.set_attributes(firstname=u'bouah')
-        self.assertEquals(e.dc_title(), 'member')
-        self.assertEquals(e.name(), u'bouah')
+        self.assertEqual(e.dc_title(), 'member')
+        self.assertEqual(e.name(), u'bouah')
         e.set_attributes(surname=u'lôt')
-        self.assertEquals(e.dc_title(), 'member')
-        self.assertEquals(e.name(), u'bouah lôt')
+        self.assertEqual(e.dc_title(), 'member')
+        self.assertEqual(e.name(), u'bouah lôt')
 
     def test_allowed_massmail_keys(self):
         e = self.execute('CWUser U WHERE U login "member"').get_entity(0, 0)
         # Bytes/Password attributes should be omited
-        self.assertEquals(e.cw_adapt_to('IEmailable').allowed_massmail_keys(),
+        self.assertEqual(e.cw_adapt_to('IEmailable').allowed_massmail_keys(),
                           set(('surname', 'firstname', 'login', 'last_login_time',
                                'creation_date', 'modification_date', 'cwuri', 'eid'))
                           )
@@ -144,7 +144,7 @@ class SpecializedEntityClassesTC(CubicWebTC):
         # no specific class for Subdivisions, the default one should be selected
         eclass = self.select_eclass('SubDivision')
         self.failUnless(eclass.__autogenerated__)
-        #self.assertEquals(eclass.__bases__, (AnyEntity,))
+        #self.assertEqual(eclass.__bases__, (AnyEntity,))
         # build class from most generic to most specific and make
         # sure the most specific is always selected
         self.vreg._loadedmods[__name__] = {}
@@ -156,12 +156,12 @@ class SpecializedEntityClassesTC(CubicWebTC):
             self.failUnless(eclass.__autogenerated__)
             self.failIf(eclass is Foo)
             if etype == 'SubDivision':
-                self.assertEquals(eclass.__bases__, (Foo,))
+                self.assertEqual(eclass.__bases__, (Foo,))
             else:
-                self.assertEquals(eclass.__bases__[0].__bases__, (Foo,))
+                self.assertEqual(eclass.__bases__[0].__bases__, (Foo,))
         # check Division eclass is still selected for plain Division entities
         eclass = self.select_eclass('Division')
-        self.assertEquals(eclass.__regid__, 'Division')
+        self.assertEqual(eclass.__regid__, 'Division')
 
 if __name__ == '__main__':
     unittest_main()
