@@ -45,6 +45,12 @@ class TwistedConfiguration(WebConfiguration):
           'help': 'http server port number (default to 8080)',
           'group': 'web', 'level': 0,
           }),
+        ('interface',
+         {'type' : 'string',
+          'default': "",
+          'help': 'http server address on which to listen (default to everywhere)',
+          'group': 'web', 'level': 0,
+          }),
         ('max-post-length',
          {'type' : 'bytes',
           'default': '100MB',
