@@ -15,9 +15,8 @@
 #
 # You should have received a copy of the GNU Lesser General Public License along
 # with CubicWeb.  If not, see <http://www.gnu.org/licenses/>.
-"""Some i18n/gettext utilities.
+"""Some i18n/gettext utilities."""
 
-"""
 __docformat__ = "restructuredtext en"
 
 import re
