@@ -234,8 +234,8 @@ class Repository(object):
 
     def init_sources_from_database(self):
         self.sources_by_eid = {}
-        if not 'CWSource' in self.schema:
-            # 3.10 migration
+        if self.config.quick_start \
+               or not 'CWSource' in self.schema: # # 3.10 migration
             return
         session = self.internal_session()
         try:
@@ -590,7 +590,7 @@ class Repository(object):
         sources = {}
         # remove sensitive information
         for uri, source in self.sources_by_uri.iteritems():
-            sources[uri] = source.cfg
+            sources[uri] = source.public_config
         return sources
 
     def properties(self):
@@ -1088,17 +1088,16 @@ class Repository(object):
         hook.CleanupNewEidsCacheOp.get_instance(session).add_data(entity.eid)
         self.system_source.add_info(session, entity, source, extid, complete)
 
-    def delete_info(self, session, entity, sourceuri, extid):
+    def delete_info(self, session, entity, sourceuri, extid, scleanup=False):
         """called by external source when some entity known by the system source
         has been deleted in the external source
         """
         # mark eid as being deleted in session info and setup cache update
         # operation
         hook.CleanupDeletedEidsCacheOp.get_instance(session).add_data(entity.eid)
-        self._delete_info(session, entity, sourceuri, extid)
+        self._delete_info(session, entity, sourceuri, extid, scleanup)
 
-    def _delete_info(self, session, entity, sourceuri, extid):
-                     # attributes=None, relations=None):
+    def _delete_info(self, session, entity, sourceuri, extid, scleanup=False):
         """delete system information on deletion of an entity:
         * delete all remaining relations from/to this entity
         * call delete info on the system source which will transfer record from
@@ -1119,7 +1118,15 @@ class Repository(object):
                     rql = 'DELETE X %s Y WHERE X eid %%(x)s' % rtype
                 else:
                     rql = 'DELETE Y %s X WHERE X eid %%(x)s' % rtype
-                session.execute(rql, {'x': eid}, build_descr=False)
+                if scleanup:
+                    # source cleaning: only delete relations stored locally
+                    rql += ', NOT (Y cw_source S, S name %(source)s)'
+                try:
+                    session.execute(rql, {'x': eid, 'source': sourceuri},
+                                    build_descr=False)
+                except:
+                    self.exception('error while cascading delete for entity %s '
+                                   'from %s. RQL: %s', entity, sourceuri, rql)
         self.system_source.delete_info(session, entity, sourceuri, extid)
 
     def locate_relation_source(self, session, subject, rtype, object):
@@ -1343,8 +1350,9 @@ class Repository(object):
 
     # pyro handling ###########################################################
 
-    def pyro_register(self, host=''):
-        """register the repository as a pyro object"""
+    @property
+    @cached
+    def pyro_appid(self):
         from logilab.common import pyro_ext as pyro
         config = self.config
         appid = '%s.%s' % pyro.ns_group_and_id(
@@ -1352,13 +1360,27 @@ class Repository(object):
             config['pyro-ns-group'])
         # ensure config['pyro-instance-id'] is a full qualified pyro name
         config['pyro-instance-id'] = appid
-        daemon = pyro.register_object(self, appid,
-                                      daemonhost=config['pyro-host'],
-                                      nshost=config['pyro-ns-host'])
-        self.info('repository registered as a pyro object %s', appid)
+        return appid
+
+    def pyro_register(self, host=''):
+        """register the repository as a pyro object"""
+        from logilab.common import pyro_ext as pyro
+        daemon = pyro.register_object(self, self.pyro_appid,
+                                      daemonhost=self.config['pyro-host'],
+                                      nshost=self.config['pyro-ns-host'])
+        self.info('repository registered as a pyro object %s', self.pyro_appid)
         self.pyro_registered = True
+        # register a looping task to regularly ensure we're still registered
+        # into the pyro name server
+        self.looping_task(60*10, self._ensure_pyro_ns)
         return daemon
 
+    def _ensure_pyro_ns(self):
+        from logilab.common import pyro_ext as pyro
+        pyro.ns_reregister(self.pyro_appid, nshost=self.config['pyro-ns-host'])
+        self.info('repository re-registered as a pyro object %s',
+                  self.pyro_appid)
+
     # multi-sources planner helpers ###########################################
 
     @cached
