@@ -126,8 +126,9 @@ def deserialize_schema(schema, session):
                 sqlexec('UPDATE %(p)sCWEType SET %(p)sname=%%(n)s WHERE %(p)seid=%%(x)s'
                         % {'p': sqlutils.SQL_PREFIX}, {'x': eid, 'n': netype})
                 if etype.lower() != netype.lower():
-                    sqlexec('ALTER TABLE %s%s RENAME TO %s%s' % (
-                        sqlutils.SQL_PREFIX, etype, sqlutils.SQL_PREFIX, netype))
+                    alter_table_sql = dbhelper.sql_rename_table(sqlutils.SQL_PREFIX+etype,
+                                                                sqlutils.SQL_PREFIX+netype)
+                    sqlexec(alter_table_sql)
             sqlexec('UPDATE entities SET type=%(n)s WHERE type=%(x)s',
                     {'x': etype, 'n': netype})
             session.commit(False)
@@ -234,7 +235,7 @@ def deserialize_schema(schema, session):
             uniquecstreid, eeid, releid = values
             eschema = schema.schema_by_eid(eeid)
             relations = unique_togethers.setdefault(uniquecstreid, (eschema, []))
-            relations[1].append(ertidx[releid].rtype.type)
+            relations[1].append(ertidx[releid])
         for eschema, unique_together in unique_togethers.itervalues():
             eschema._unique_together.append(tuple(sorted(unique_together)))
     schema.infer_specialization_rules()
@@ -354,6 +355,7 @@ def serialize_schema(cursor, schema):
     for eschema in eschemas:
         for unique_together in eschema._unique_together:
             execschemarql(execute, eschema, [uniquetogether2rql(eschema, unique_together)])
+    # serialize yams inheritance relationships
     for rql, kwargs in specialize2rql(schema):
         execute(rql, kwargs, build_descr=False)
         if pb is not None:
@@ -416,23 +418,17 @@ def uniquetogether2rql(eschema, unique_together):
     restrictions = []
     substs = {}
     for i, name in enumerate(unique_together):
-        rschema = eschema.rdef(name)
-        var = 'R%d' % i
+        rschema = eschema.schema.rschema(name)
         rtype = 'T%d' % i
-        substs[rtype] = rschema.rtype.type
-        relations.append('C relations %s' % var)
-        restrictions.append('%(var)s from_entity X, '
-                            '%(var)s relation_type %(rtype)s, '
-                            '%(rtype)s name %%(%(rtype)s)s' \
-                            % {'var': var,
-                               'rtype':rtype})
+        substs[rtype] = rschema.type
+        relations.append('C relations %s' % rtype)
+        restrictions.append('%(rtype)s name %%(%(rtype)s)s' % {'rtype': rtype})
     relations = ', '.join(relations)
     restrictions = ', '.join(restrictions)
     rql = ('INSERT CWUniqueTogetherConstraint C: '
            '    C constraint_of X, %s  '
            'WHERE '
-           '    X eid %%(x)s, %s' )
-
+           '    X eid %%(x)s, %s')
     return rql % (relations, restrictions), substs
 
 
