@@ -78,12 +78,12 @@ def ask_source_config(appconfig, type, inputlevel=0):
     sconfig.input_config(inputlevel=inputlevel)
     return sconfig
 
-def generate_source_config(sconfig):
+def generate_source_config(sconfig, encoding=sys.stdin.encoding):
     """serialize a repository source configuration as text"""
     stream = StringIO()
     optsbysect = list(sconfig.options_by_section())
     assert len(optsbysect) == 1, 'all options for a source should be in the same group'
-    lgconfig.ini_format(stream, optsbysect[0][1], sys.stdin.encoding)
+    lgconfig.ini_format(stream, optsbysect[0][1], encoding)
     return stream.getvalue()
 
 
@@ -297,7 +297,12 @@ and if not set, it will be choosen randomly',
                 _sconfig = SourceConfiguration(
                     self, options=SOURCE_TYPES['native'].options)
                 for attr, val in sconfig.items():
-                    _sconfig.set_option(attr, val)
+                    try:
+                        _sconfig.set_option(attr, val)
+                    except lgconfig.OptionError:
+                        # skip adapter, may be present on pre 3.10 instances
+                        if attr != 'adapter':
+                            self.error('skip unknown option %s in sources file')
                 sconfig = _sconfig
             print >> stream, '[%s]' % section
             print >> stream, generate_source_config(sconfig)
