@@ -237,6 +237,7 @@ class RepositoryStartHandler(CommandHandler):
         command.append('--loglevel %s' % config['log-threshold'].lower())
         command.append(config.appid)
         os.system(' '.join(command))
+        return 1
 
 
 class RepositoryStopHandler(CommandHandler):
@@ -550,7 +551,7 @@ class ResetAdminPasswordCommand(Command):
 
 
 class StartRepositoryCommand(Command):
-    """Start an CubicWeb RQL server for a given instance.
+    """Start a CubicWeb RQL server for a given instance.
 
     The server will be accessible through pyro
 
@@ -593,7 +594,7 @@ class StartRepositoryCommand(Command):
         # go ! (don't daemonize in debug mode)
         if not os.path.exists(piddir):
             os.makedirs(piddir)
-        if not debug and daemonize(pidfile):
+        if not debug and daemonize(pidfile, umask=config['umask']):
             return
         uid = config['uid']
         if uid is not None:
