@@ -55,7 +55,7 @@ class TimedCache(dict):
     def __init__(self, ttl):
         # time to live in seconds
         if ttl <= 0:
-            raise ValueError('TimedCache initialized with a ttl of %ss' % self.ttl.seconds)
+            raise ValueError('TimedCache initialized with a ttl of %ss' % ttl.seconds)
         self.ttl = timedelta(seconds=ttl)
 
     def __setitem__(self, key, value):
@@ -109,8 +109,8 @@ class AbstractSource(object):
         self.set_schema(repo.schema)
         self.support_relations['identity'] = False
         self.eid = None
-        self.cfg = source_config.copy()
-        self.remove_sensitive_information(self.cfg)
+        self.public_config = source_config.copy()
+        self.remove_sensitive_information(self.public_config)
 
     def init_creating(self):
         """method called by the repository once ready to create a new instance"""
