@@ -126,6 +126,12 @@ to respond to rql queries).',
           'help': 'classes of user',
           'group': 'ldap-source', 'level': 1,
           }),
+        ('user-filter',
+         {'type': 'string',
+          'default': '',
+          'help': 'additional filters to be set in the ldap query to find valid users',
+          'group': 'ldap-source', 'level': 2,
+          }),
         ('user-login-attr',
          {'type' : 'string',
           'default': 'uid',
@@ -177,11 +183,11 @@ directory (default to once a day).',
         self.user_login_attr = source_config['user-login-attr']
         self.user_default_groups = splitstrip(source_config['user-default-group'])
         self.user_attrs = dict(v.split(':', 1) for v in splitstrip(source_config['user-attrs-map']))
+        self.user_filter = source_config.get('user-filter')
         self.user_rev_attrs = {'eid': 'dn'}
         for ldapattr, cwattr in self.user_attrs.items():
             self.user_rev_attrs[cwattr] = ldapattr
-        self.base_filters = [filter_format('(%s=%s)', ('objectClass', o))
-                              for o in self.user_classes]
+        self.base_filters = self._make_base_filters()
         self._conn = None
         self._cache = {}
         # ttlm is in minutes!
@@ -194,6 +200,13 @@ directory (default to once a day).',
                                     source_config.get('synchronization-interval',
                                                       24*60*60))
 
+    def _make_base_filters(self):
+        filters =  [filter_format('(%s=%s)', ('objectClass', o))
+                              for o in self.user_classes] 
+        if self.user_filter:
+            filters += [self.user_filter]
+        return filters
+
     def reset_caches(self):
         """method called during test to reset potential source caches"""
         self._cache = {}
@@ -266,7 +279,10 @@ directory (default to once a day).',
     def get_connection(self):
         """open and return a connection to the source"""
         if self._conn is None:
-            self._connect()
+            try:
+                self._connect()
+            except:
+                self.exception('cant connect to ldap')
         return ConnectionWrapper(self._conn)
 
     def authenticate(self, session, login, password=None, **kwargs):
@@ -283,8 +299,7 @@ directory (default to once a day).',
             # we really really don't want that
             raise AuthenticationError()
         searchfilter = [filter_format('(%s=%s)', (self.user_login_attr, login))]
-        searchfilter.extend([filter_format('(%s=%s)', ('objectClass', o))
-                             for o in self.user_classes])
+        searchfilter.extend(self._make_base_filters())
         searchstr = '(&%s)' % ''.join(searchfilter)
         # first search the user
         try:
@@ -366,8 +381,14 @@ directory (default to once a day).',
         try:
             results = self._query_cache[rqlkey]
         except KeyError:
-            results = self.rqlst_search(session, rqlst, args)
-            self._query_cache[rqlkey] = results
+            try:
+                results = self.rqlst_search(session, rqlst, args)
+                self._query_cache[rqlkey] = results
+            except ldap.SERVER_DOWN:
+                # cant connect to server
+                msg = session._("can't connect to source %s, some data may be missing")
+                session.set_shared_data('sources_error', msg % self.uri)
+                return []
         return results
 
     def rqlst_search(self, session, rqlst, args):
