@@ -24,7 +24,7 @@ _ = unicode
 
 from warnings import warn
 
-from logilab.common.deprecation import class_deprecated, class_renamed
+from logilab.common.deprecation import class_deprecated, class_renamed, deprecated
 from logilab.mtconverter import xml_escape
 
 from cubicweb import Unauthorized, role, target, tags
@@ -36,7 +36,7 @@ from cubicweb.selectors import (no_cnx, paginated_rset, one_line_rset,
                                 non_final_entity, partial_relation_possible,
                                 partial_has_related_entities)
 from cubicweb.appobject import AppObject
-from cubicweb.web import INTERNAL_FIELD_VALUE, htmlwidgets, stdmsgs
+from cubicweb.web import INTERNAL_FIELD_VALUE, stdmsgs
 
 
 # abstract base class for navigation components ################################
@@ -116,7 +116,7 @@ class NavigationComponent(Component):
         # XXX hack to avoid opening a new page containing the evaluation of the
         # js expression on ajax call
         if url.startswith('javascript:'):
-            url += '; noop();'
+            url += '; $.noop();'
         return url
 
     def ajax_page_url(self, **params):
@@ -163,6 +163,57 @@ class EmptyComponent(Exception):
     rendered
     """
 
+
+class Link(object):
+    """a link to a view or action in the ui.
+
+    Use this rather than `cw.web.htmlwidgets.BoxLink`.
+
+    Note this class could probably be avoided with a proper DOM on the server
+    side.
+    """
+    newstyle = True
+
+    def __init__(self, href, label, **attrs):
+        self.href = href
+        self.label = label
+        self.attrs = attrs
+
+    def __unicode__(self):
+        return tags.a(self.label, href=self.href, **self.attrs)
+
+    def render(self, w):
+        w(tags.a(self.label, href=self.href, **self.attrs))
+
+
+class Separator(object):
+    """a menu separator.
+
+    Use this rather than `cw.web.htmlwidgets.BoxSeparator`.
+    """
+    newstyle = True
+
+    def render(self, w):
+        w(u'<hr class="boxSeparator"/>')
+
+
+def _bwcompatible_render_item(w, item):
+    if hasattr(item, 'render'):
+        if getattr(item, 'newstyle', False):
+            if isinstance(item, Separator):
+                w(u'</ul>')
+                item.render(w)
+                w(u'<ul>')
+            else:
+                w(u'<li>')
+                item.render(w)
+                w(u'</li>')
+        else:
+            item.render(w) # XXX displays <li> by itself
+    else:
+        w(u'<li>%s</li>' % item)
+
+
 class Layout(Component):
     __regid__ = 'layout'
     __abstract__ = True
@@ -183,7 +234,7 @@ class Layout(Component):
 
 
 class CtxComponent(AppObject):
-    """base class for contextual compontents. The following contexts are
+    """base class for contextual components. The following contexts are
     predefined:
 
     * boxes: 'left', 'incontext', 'right'
@@ -191,12 +242,12 @@ class CtxComponent(AppObject):
     * other: 'ctxtoolbar'
 
     The 'incontext', 'navcontenttop', 'navcontentbottom' and 'ctxtoolbar'
-    context are handled by the default primary view, others by the default main
+    contexts are handled by the default primary view, others by the default main
     template.
 
     All subclasses may not support all those contexts (for instance if it can't
     be displayed as box, or as a toolbar icon). You may restrict allowed context
-    as followed:
+    as follows:
 
     .. sourcecode:: python
 
@@ -205,8 +256,8 @@ class CtxComponent(AppObject):
                                           vocabulary=[list of contexts])
           context = 'my default context'
 
-    You can configure default component's context by simply giving appropriate
-    value to the `context` class attribute, as seen above.
+    You can configure a component's default context by simply giving an
+    appropriate value to the `context` class attribute, as seen above.
     """
     __registry__ = 'ctxcomponents'
     __select__ = ~no_cnx()
@@ -234,7 +285,7 @@ class CtxComponent(AppObject):
     # argument
     def render(self, w, **kwargs):
         if hasattr(self, 'call'):
-            warn('[3.10] should not anymore implements call on %s, see new CtxComponent api'
+            warn('[3.10] should not anymore implement call on %s, see new CtxComponent api'
                  % self.__class__, DeprecationWarning)
             self.w = w
             def wview(__vid, rset=None, __fallback_vid=None, **kwargs):
@@ -289,20 +340,31 @@ class CtxComponent(AppObject):
         assert items
         w(u'<ul class="%s">' % klass)
         for item in items:
-            if hasattr(item, 'render'):
-                item.render(w) # XXX display <li> by itself
-            else:
-                w(u'<li>')
-                w(item)
-                w(u'</li>')
+            _bwcompatible_render_item(w, item)
         w(u'</ul>')
 
     def append(self, item):
         self.items.append(item)
 
+    def action_link(self, action):
+        return self.link(self._cw._(action.title), action.url())
+
+    def link(self, title, url, **kwargs):
+        if self._cw.selected(url):
+            try:
+                kwargs['klass'] += ' selected'
+            except KeyError:
+                kwargs['klass'] = 'selected'
+        return Link(url, title, **kwargs)
+
+    def separator(self):
+        return Separator()
+
+    @deprecated('[3.10] use action_link() / link()')
     def box_action(self, action): # XXX action_link
         return self.build_link(self._cw._(action.title), action.url())
 
+    @deprecated('[3.10] use action_link() / link()')
     def build_link(self, title, url, **kwargs):
         if self._cw.selected(url):
             try:
@@ -334,30 +396,39 @@ class EntityCtxComponent(CtxComponent):
 # high level abstract classes ##################################################
 
 class RQLCtxComponent(CtxComponent):
-    """abstract box for boxes displaying the content of a rql query not
-    related to the current result set.
+    """abstract box for boxes displaying the content of a rql query not related
+    to the current result set.
+
+    Notice that this class's init_rendering implemention is overwriting context
+    result set (eg `cw_rset`) with the result set returned by execution of
+    `to_display_rql()`.
     """
-    rql  = None
+    rql = None
 
     def to_display_rql(self):
+        """return arguments to give to self._cw.execute, as a tuple, to build
+        the result set to be displayed by this box.
+        """
         assert self.rql is not None, self.__regid__
         return (self.rql,)
 
     def init_rendering(self):
-        rset = self._cw.execute(*self.to_display_rql())
-        if not rset:
+        super(RQLCtxComponent, self).init_rendering()
+        self.cw_rset = self._cw.execute(*self.to_display_rql())
+        if not self.cw_rset:
             raise EmptyComponent()
-        if len(rset[0]) == 2:
-            self.items = []
-            for i, (eid, label) in enumerate(rset):
-                entity = rset.get_entity(i, 0)
-                self.items.append(self.build_link(label, entity.absolute_url()))
-        else:
-            self.items = [self.build_link(e.dc_title(), e.absolute_url())
-                          for e in rset.entities()]
 
     def render_body(self, w):
-        self.render_items(w)
+        rset = self.cw_rset
+        if len(rset[0]) == 2:
+            items = []
+            for i, (eid, label) in enumerate(rset):
+                entity = rset.get_entity(i, 0)
+                items.append(self.link(label, entity.absolute_url()))
+        else:
+            items = [self.link(e.dc_title(), e.absolute_url())
+                     for e in rset.entities()]
+        self.render_items(w, items)
 
 
 class EditRelationMixIn(ReloadableMixIn):
@@ -366,8 +437,8 @@ class EditRelationMixIn(ReloadableMixIn):
         args = {role(self)[0] : entity.eid, target(self)[0] : etarget.eid}
         url = self._cw.user_rql_callback((rql, args))
         # for each target, provide a link to edit the relation
-        return u'[<a href="%s">%s</a>] %s' % (xml_escape(url), label,
-                                              etarget.view('incontext'))
+        return u'[<a href="%s" class="action">%s</a>] %s' % (
+            xml_escape(url), label, etarget.view('incontext'))
 
     def related_boxitems(self, entity):
         rql = 'DELETE S %s O WHERE S eid %%(s)s, O eid %%(o)s' % self.rtype
@@ -403,7 +474,7 @@ class EditRelationMixIn(ReloadableMixIn):
                     entities.append(entity)
         return entities
 
-
+# XXX should be a view usable using uicfg
 class EditRelationCtxComponent(EditRelationMixIn, EntityCtxComponent):
     """base class for boxes which let add or remove entities linked by a given
     relation
@@ -411,8 +482,8 @@ class EditRelationCtxComponent(EditRelationMixIn, EntityCtxComponent):
     subclasses should define at least id, rtype and target class attributes.
     """
     def render_title(self, w):
-        return display_name(self._cw, self.rtype, role(self),
-                            context=self.entity.__regid__)
+        w(display_name(self._cw, self.rtype, role(self),
+                       context=self.entity.__regid__))
 
     def render_body(self, w):
         self._cw.add_js('cubicweb.ajax.js')
@@ -420,7 +491,7 @@ class EditRelationCtxComponent(EditRelationMixIn, EntityCtxComponent):
         unrelated = self.unrelated_boxitems(self.entity)
         self.items.extend(related)
         if related and unrelated:
-            self.items.append(htmlwidgets.BoxSeparator())
+            self.items.append(u'<hr class="boxSeparator"/>')
         self.items.extend(unrelated)
         self.render_items(w)
 
