@@ -36,12 +36,10 @@ jQuery.extend(Deferred.prototype, {
     },
 
     addCallback: function(callback) {
-        if (this._req.readyState == 4) {
-            if (this._result) {
-                var args = [this._result, this._req];
-                jQuery.merge(args, cw.utils.sliceList(arguments, 1));
-                callback.apply(null, args);
-            }
+        if ((this._req.readyState == 4) && this._result) {
+            var args = [this._result, this._req];
+            jQuery.merge(args, cw.utils.sliceList(arguments, 1));
+            callback.apply(null, args);
         }
         else {
             this._onSuccess.push([callback, cw.utils.sliceList(arguments, 1)]);
@@ -50,10 +48,8 @@ jQuery.extend(Deferred.prototype, {
     },
 
     addErrback: function(callback) {
-        if (this._req.readyState == 4) {
-            if (this._error) {
-                callback.apply(null, [this._error, this._req]);
-            }
+        if (this._req.readyState == 4 && this._error) {
+            callback.apply(null, [this._error, this._req]);
         }
         else {
             this._onFailure.push([callback, cw.utils.sliceList(arguments, 1)]);
@@ -294,7 +290,7 @@ function loadRemote(url, form, reqtype, sync) {
         var deferred = new Deferred();
         jQuery.ajax({
             url: url,
-            type: (reqtype || 'GET').toUpperCase(),
+            type: (reqtype || 'POST').toUpperCase(),
             data: form,
             traditional: true,
             async: true,
@@ -322,12 +318,21 @@ function loadRemote(url, form, reqtype, sync) {
         });
         return deferred;
     } else {
-        var result = jQuery.ajax({
+        var result;
+        // jQuery.ajax returns the XHR object, even for synchronous requests,
+        // but in that case, the success callback will be called before
+        // jQuery.ajax returns. The first argument of the callback will be
+        // the server result, interpreted by jQuery according to the reponse's
+        // content-type (i.e. json or xml)
+        jQuery.ajax({
             url: url,
             type: (reqtype || 'GET').toUpperCase(),
             data: form,
             traditional: true,
-            async: false
+            async: false,
+            success: function(res) {
+                result = res;
+            }
         });
         return result;
     }
