@@ -11,7 +11,7 @@
 /**
  * .. function:: setPropValueWidget(varname, tabindex)
  *
- * called on Eproperty key selection:
+ * called on CWProperty key selection:
  * - get the selected value
  * - get a widget according to the key by a sync query to the server
  * - fill associated div with the returned html
@@ -65,12 +65,12 @@ function showMatchingSelect(selectedValue, eid) {
                 vid: 'unrelateddivs',
                 relation: selectedValue,
                 rql: rql_for_eid(eid),
-                '__notemplate': 1,
-                callback: function() {
-                    _showMatchingSelect(eid, jQuery('#' + divId));
-                }
+                '__notemplate': 1
             };
-            jQuery('#unrelatedDivs_' + eid).loadxhtml(baseuri() + 'view', args, 'post', 'append');
+            var d = jQuery('#unrelatedDivs_' + eid).loadxhtml(baseuri() + 'view', args, 'post', 'append');
+            d.addCallback(function() {
+                _showMatchingSelect(eid, jQuery('#' + divId));
+            });
         } else {
             _showMatchingSelect(eid, divNode);
         }
@@ -209,7 +209,7 @@ function cancelPendingInsert(elementId, element_name, comboId, eid) {
         }
     }
     elementId = elementId.substring(2, elementId.length);
-    loadRemote('json', ajaxFuncArgs('remove_pending_inserts', null,
+    loadRemote('json', ajaxFuncArgs('remove_pending_insert', null,
                                     elementId.split(':')), 'GET', true);
 }
 
@@ -265,7 +265,7 @@ function cancelPendingDelete(nodeId, eid) {
  */
 function togglePendingDelete(nodeId, eid) {
     // node found means we should cancel deletion
-    if (jQuery.className.has(cw.getNode('span' + nodeId), 'pendingDelete')) {
+    if (jQuery(cw.getNode('span' + nodeId)).hasClass('pendingDelete')) {
         cancelPendingDelete(nodeId, eid);
     } else {
         addPendingDelete(nodeId, eid);
