@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # copyright 2003-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
 #
@@ -21,12 +20,14 @@ object to handle publication.
 """
 
 __docformat__ = "restructuredtext en"
+_ = unicode
 
 from logilab.common.date import strptime
 
 from cubicweb import (NoSelectableObject, ObjectNotFound, ValidationError,
                       AuthenticationError, typed_eid)
 from cubicweb.utils import UStringIO, json, json_dumps
+from cubicweb.uilib import exc_message
 from cubicweb.selectors import authenticated_user, anonymous_user, match_form_params
 from cubicweb.mail import format_mail
 from cubicweb.web import Redirect, RemoteCallFailed, DirectResponse
@@ -120,7 +121,7 @@ class ViewController(Controller):
         self.validate_cache(view)
         template = self.appli.main_template_id(self._cw)
         return self._cw.vreg['views'].main_template(self._cw, template,
-                                                rset=rset, view=view)
+                                                    rset=rset, view=view)
 
     def _select_view_and_rset(self, rset):
         req = self._cw
@@ -252,6 +253,7 @@ def optional_kwargs(extraargs):
     # we receive unicode keys which is not supported by the **syntax
     return dict((str(key), value) for key, value in extraargs.iteritems())
 
+
 class JSonController(Controller):
     __regid__ = 'json'
 
@@ -281,15 +283,15 @@ class JSonController(Controller):
         except ValueError, exc:
             self.exception('error while decoding json arguments for js_%s: %s',
                            fname, args, exc)
-            raise RemoteCallFailed(repr(exc))
+            raise RemoteCallFailed(exc_message(exc, self._cw.encoding))
         try:
             result = func(*args)
         except (RemoteCallFailed, DirectResponse):
             raise
-        except Exception, ex:
+        except Exception, exc:
             self.exception('an exception occurred while calling js_%s(%s): %s',
-                           fname, args, ex)
-            raise RemoteCallFailed(repr(ex))
+                           fname, args, exc)
+            raise RemoteCallFailed(exc_message(exc, self._cw.encoding))
         if result is None:
             return ''
         # get unicode on @htmlize methods, encoded string on @jsonize methods
@@ -417,7 +419,7 @@ class JSonController(Controller):
                                               **optional_kwargs(extraargs))
         #except NoSelectableObject:
         #    raise RemoteCallFailed('unselectable')
-        return self._call_view(comp, **extraargs)
+        return self._call_view(comp, **optional_kwargs(extraargs))
 
     @xhtmlize
     def js_render(self, registry, oid, eid=None,
@@ -584,7 +586,9 @@ class MailBugReportController(Controller):
 
     def publish(self, rset=None):
         body = self._cw.form['description']
-        self.sendmail(self._cw.config['submit-mail'], _('%s error report') % self._cw.config.appid, body)
+        self.sendmail(self._cw.config['submit-mail'],
+                      self._cw._('%s error report') % self._cw.config.appid,
+                      body)
         url = self._cw.build_url(__message=self._cw._('bug report sent'))
         raise Redirect(url)
 
@@ -596,11 +600,10 @@ class UndoController(Controller):
     def publish(self, rset=None):
         txuuid = self._cw.form['txuuid']
         errors = self._cw.cnx.undo_transaction(txuuid)
-        if errors:
-            self.w(self._cw._('some errors occurred:'))
-            self.wview('pyvalist', pyvalue=errors)
-        else:
+        if not errors:
             self.redirect()
+        return self._cw._('some errors occurred:') + self.view('pyvalist',
+                                                               pyvalue=errors)
 
     def redirect(self):
         req = self._cw
