@@ -188,7 +188,7 @@ class MetaDataView(EntityView):
     def cell_call(self, row, col):
         _ = self._cw._
         entity = self.cw_rset.get_entity(row, col)
-        self.w(u'<div class="metadata">')
+        self.w(u'<div>')
         if self.show_eid:
             self.w(u'%s #%s - ' % (entity.dc_type(), entity.eid))
         if entity.modification_date != entity.creation_date:
@@ -359,7 +359,7 @@ class CSVView(SimpleListView):
 
     def call(self, subvid=None, **kwargs):
         if subvid is None and 'vid' in kwargs:
-            warn("should give a 'subvid' argument instead of 'vid'",
+            warn("[3.9] should give a 'subvid' argument instead of 'vid'",
                  DeprecationWarning, stacklevel=2)
         else:
             kwargs['vid'] = subvid
