@@ -22,6 +22,7 @@ _ = unicode
 
 from warnings import warn
 
+from logilab.common.deprecation import deprecated
 from logilab.mtconverter import xml_escape
 
 from cubicweb import Unauthorized, NoSelectableObject
@@ -68,7 +69,15 @@ class PrimaryView(EntityView):
             boxes = None
         if boxes or hasattr(self, 'render_side_related'):
             self.w(u'<table width="100%"><tr><td style="width: 75%">')
-        self.render_entity_summary(entity)
+        if hasattr(self, 'render_entity_summary'):
+            warn('[3.10] render_entity_summary method is deprecated (%s)' % self,
+                 DeprecationWarning)
+            self.render_entity_summary(entity)
+        summary = self.summary(entity)
+        if summary:
+            warn('[3.10] summary method is deprecated (%s)' % self,
+                 DeprecationWarning)
+            self.w(u'<div class="summary">%s</div>' % summary)
         self.w(u'<div class="mainInfo">')
         self.content_navigation_components('navcontenttop')
         self.render_entity_attributes(entity)
@@ -93,10 +102,8 @@ class PrimaryView(EntityView):
             self._cw, rset=self.cw_rset, view=self, context=context):
             try:
                 comp.render(w=self.w, row=self.cw_row, view=self)
-            except NotImplementedError:
-                warn('[3.2] component %s doesnt implement cell_call, please update'
-                     % comp.__class__, DeprecationWarning)
-                comp.render(w=self.w, view=self)
+            except TypeError:
+                comp.render(w=self.w)
         self.w(u'</div>')
 
     def render_entity_title(self, entity):
@@ -113,14 +120,10 @@ class PrimaryView(EntityView):
     def render_entity_toolbox(self, entity):
         self.content_navigation_components('ctxtoolbar')
 
+    @deprecated('[3.8] render_entity_metadata method is deprecated')
     def render_entity_metadata(self, entity):
         entity.view('metadata', w=self.w)
 
-    def render_entity_summary(self, entity):
-        summary = self.summary(entity) # deprecate summary?
-        if summary:
-            self.w(u'<div class="summary">%s</div>' % summary)
-
     def summary(self, entity):
         """default implementation return an empty string"""
         return u''
@@ -229,11 +232,8 @@ class PrimaryView(EntityView):
             else:
                  try:
                      box.render(w=self.w, row=self.cw_row)
-                 except NotImplementedError:
-                    # much probably a context insensitive box, which only
-                    # implements .call() and not cell_call()
-                    # XXX shouldn't occurs with the new box system
-                    box.render(w=self.w)
+                 except TypeError:
+                     box.render(w=self.w)
 
     def _prepare_side_boxes(self, entity):
         sideboxes = []
@@ -371,13 +371,13 @@ class AttributeView(EntityView):
     __regid__ = 'attribute'
     __select__ = EntityView.__select__ & match_kwargs('rtype')
 
-    def cell_call(self, row, col, rtype, **kwargs):
+    def cell_call(self, row, col, rtype, role, **kwargs):
         entity = self.cw_rset.get_entity(row, col)
         if self._cw.vreg.schema.rschema(rtype).final:
             self.w(entity.printable_value(rtype))
         else:
             dispctrl = uicfg.primaryview_display_ctrl.etype_get(
-                entity.e_schema, rtype, kwargs['role'], '*')
+                entity.e_schema, rtype, role, '*')
             rset = entity.related(rtype, role)
             if rset:
                 self.wview('autolimited', rset, initargs={'dispctrl': dispctrl})
