@@ -163,7 +163,7 @@ def update_form(**kwargs):
     return do_build_rset
 
 def rgx_action(rql=None, args=None, cachekey=None, argsgroups=(), setuser=False,
-               form=None, formgroups=(), transforms={}, controller=None):
+               form=None, formgroups=(), transforms={}, rqlformparams=(), controller=None):
     def do_build_rset(inputurl, uri, req, schema,
                       cachekey=cachekey # necessary to avoid UnboundLocalError
                       ):
@@ -183,6 +183,8 @@ def rgx_action(rql=None, args=None, cachekey=None, argsgroups=(), setuser=False,
                         kwargs[key] = typed_eid(value)
             if setuser:
                 kwargs['u'] = req.user.eid
+            for param in rqlformparams:
+                kwargs.setdefault(param, req.form.get(param))
             rset = req.execute(rql, kwargs, cachekey)
         else:
             rset = None
